@@ -9,7 +9,7 @@ use Scalar::Util qw(weaken);
 use EO::Hash;
 #use EO::Locale;
 
-our $VERSION = 0.90;
+our $VERSION = "0.91";
 our @ISA = qw(EO);
 
 exception EO::Error::InvalidParameter;
@@ -139,44 +139,14 @@ EO::Data - holds data
 
 =head1 DESCRIPTION
 
-Stub documentation for this module was created by ExtUtils::ModuleMaker.
-It looks like the author of the extension was negligent enough
-to leave the stub unedited.
-
-Blah blah blah.
-
-
-=head1 USAGE
-
-
-
-=head1 BUGS
-
-
-
-=head1 SUPPORT
-
-
-
-=head1 AUTHOR
-
-	A. U. Thor
-	a.u.thor@a.galaxy.far.far.away
-	http://a.galaxy.far.far.away/modules
-
 =head1 COPYRIGHT
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
-The full text of the license can be found in the
-LICENSE file included with this module.
-
 
 =head1 SEE ALSO
 
-perl(1).
-
 =cut
 
 
